@@ -262,7 +262,7 @@ SMBGetFile (GtkTreeView *treeview, char *target,GList *list)
 	  print_diagnostics(treeview,"xf_ERROR_ICON",
 			  _("Only drops from a single share are allowed"),
 			  NULL);
-	  g_free(orig_share);
+	  g_free(orig_share);orig_share=NULL;
 	  return;
   }
   {
@@ -279,13 +279,16 @@ SMBGetFile (GtkTreeView *treeview, char *target,GList *list)
 			    target,file,local_file); 
 			    /*target,file,filename); */
     }
-    g_free(local_file);
+    g_free(local_file);local_file=NULL;
   }
  } /* end for list elements */
  
   fclose(tmpfile);
   SMBtmpfile=g_strdup(fname); 
-  if (filename) g_free(filename);
+  if (filename) {
+	  g_free(filename);
+	  filename=NULL;
+  }
   filename=NULL;
   /* wait until OK to proceed */
   cursor_wait (treeview);
@@ -298,7 +301,10 @@ SMBGetFile (GtkTreeView *treeview, char *target,GList *list)
 		  TRUE, 
 		  SMBStdout, 
 		  smb_stderr);
-  if (orig_share) g_free(orig_share);
+  if (orig_share) {
+	  g_free(orig_share);
+	  orig_share=NULL;
+  }
 
   return;
 }
@@ -418,7 +424,7 @@ SMBDropFile (GtkTreeView *treeview,tree_entry_t *t_en,
 		  smb_stderr);
 
   smb_wait(TRUE);
-  g_free(g);
+  g_free(g);g=NULL;
 
   remove_folder(treeview,iter);
   add_smb_stuff(treeview,iter,t_en->tag);
@@ -542,6 +548,7 @@ SMBmkdir (GtkTreeView *treeview,tree_entry_t *t_en,
   if (!IS_SAMBA_SERVER(t_en->subtype)) ascii_unreadable(name);
   command=g_strconcat("cd /;cd \"",target,"\";mkdir \"",name,"\";ls;\n",NULL);
   g_free(target);
+  target=NULL;
   
   argv[1]=g;
   argv[2]="-U";
@@ -575,8 +582,8 @@ SMBmkdir (GtkTreeView *treeview,tree_entry_t *t_en,
 		  smb_stderr);
 
   smb_wait(TRUE);
-  g_free(g);
-  g_free(command);
+  g_free(g);g=NULL;
+  g_free(command);command=NULL;
   remove_folder(treeview,iter);
   add_smb_stuff(treeview,iter,t_en->tag);
   SET_LOADED(t_en->type);
